==> nextcloud-26.0.10.tgz: nextcloud/apps/updatenotification/l10n/es_AR.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} está disponible. Obtenga más información sobre cómo actualizar.",
    "Channel updated" : "Canal actualizado",
    "Web updater is disabled" : "El actualizador web está desactivado",
    "Update notifications" : "Actualizar notificaciones",
    "The update server could not be reached since %d days to check for new updates." : "El servidor de actualización no ha podido ser alcanzado desde %d días para verificar actualizaciones. ",
    "Please check the Nextcloud and server log files for errors." : "Favor de verificar los archivos de bitacoras de Nextcloud y del servidor por errores. ",
    "Update to %1$s is available." : "La actualización a %1$s está disponible. ",
    "Update for {app} to version %s is available." : "Actualización para {app} a la versión %s está disponible.",
    "Update notification" : "Notificación de actualización",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Muestra notificaciones de actualizaciones para Nexcloud y provee el SSO para el actualizador.",
    "Update" : "Actualizar",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "La versión que usás yo no está mantenida. Por favor, asegurate de actualizar a una versión reciente tan pronto como sea posible.",
    "Apps missing compatible version" : "Apps sin versión compatible",
    "View in store" : "Ver en la tienda",
    "Apps with compatible version" : "Apps con versión compatible",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Tenga en cuenta que el actualizador web no se recomienda cuando la instancia tiene más de 100 usuarios. Por favor, utilice el actualizador de línea de comandos en su lugar.",
    "Open updater" : "Abrir actualizador",
    "Download now" : "Descargar ahora",
    "What's new?" : "¿Qué novedades hay?",
    "View changelog" : "Ver registro de cambios",
    "The update check is not yet finished. Please refresh the page." : "La comprobación de actualizaciones no ha finalizado aún. Por favor, recargá la página.",
    "Your version is up to date." : "Su versión está actualizada.",
    "A non-default update server is in use to be checked for updates:" : "Se está usando un servidor de actualizaciones no estándar para comprobar las actualizaciones:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Siempre puedes actualizar a una versión más reciente. Pero no podrás volver a una versión anterior estable.",
    "Notify members of the following groups about available updates:" : "Notificar a los miembros de los siguientes grupos de las actualizaciones disponibles:",
    "Only notifications for app updates are available." : "Solo están disponibles las notificaciones para actualizaciones de apps.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "El canal de actualización seleccionado hace que las notificaciones dedicadas al servidor sean obsoletas. ",
    "The selected update channel does not support updates of the server." : "El canal de actualización seleccionado no soporta actualizaciones del servidor. ",
    "A new version is available: <strong>{newVersionString}</strong>" : "Una versión más reciente está disponible: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Tenga en cuenta que tras un nueva lanzamiento, la actualización sólo se mostrará después de la primera versión menor o posterior. Las nuevas versiones se distribuyen entre nuestros usuarios a lo largo del tiempo y a veces se omite una versión cuando se encuentran problemas. Obtenga  más información sobre las actualizaciones y los canales de lanzamiento en {link}",
    "Checked on {lastCheckedDate}" : "Verificado el {lastCheckedDate}",
    "Checking apps for compatible versions" : "Comprobando que las apps tengan actualizaciones compatibles",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Por favor, asegurate de que tu archivo config.php no establezca <samp>appstoreenabled</samp> a \"false\".",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "No se ha podido conectar a la App Store o no se ha devuelto ninguna actualización. Busque manualmente las actualizaciones o asegúrese de que su servidor tiene acceso a Internet y pueda conectarse a la App Store.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Todas</strong> las apps son compatibles con esta versión de Nextcloud.",
    "Enterprise" : "Enterprise",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Para uso empresarial. Proporciona siempre el último nivel de actualización, pero no realiza inmediatamente la actualización a la siguiente versión mayor. La actualización ocurre cuando Nextcloud GmbH ha realizado una revisión dedicada, pruebas para despliegues a gran escala y servicios críticos. Este canal está disponible únicamente para los clientes del paquete Nextcloud Enterprise.",
    "Stable" : "Estable",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Es la versión estable más reciente. Es adecuada para uso en producción y siempre se actualizará a la última versión principal.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Es la versión preliminar para poder probar nuevas características, no para entornos de producción.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["La app <strong>%n</strong> no tiene una versión disponible compatible con esta versión de Nextcloud.","Las apps 1%n1 no tienen una versión disponible compatible con esta versión de Nextcloud.","Las apps <strong>%n</strong> no tienen una versión compatible con esta versión de Nextcloud."],
    "Please use the command line updater to update." : "Por favor, utilice el actualizador de línea de comandos para actualizar.",
    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Podés cambiar el canal de actualización a continuación, lo que también afecta a la página de gestión de aplicaciones. Por ejemplo, después de cambiar al canal beta, las actualizaciones de aplicaciones beta se ofrecerán en la página de gestión de aplicaciones.",
    "Update channel:" : "Actualizar el canal:"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-27.1.4.tgz: nextcloud/apps/updatenotification/l10n/es_AR.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} está disponible. Obtenga más información sobre cómo actualizar.",
    "Channel updated" : "Canal actualizado",
    "Web updater is disabled" : "El actualizador web está desactivado",
    "Update notifications" : "Actualizar notificaciones",
    "The update server could not be reached since %d days to check for new updates." : "El servidor de actualización no ha podido ser alcanzado desde %d días para verificar actualizaciones. ",
    "Please check the Nextcloud and server log files for errors." : "Favor de verificar los archivos de bitacoras de Nextcloud y del servidor por errores. ",
    "Update to %1$s is available." : "La actualización a %1$s está disponible. ",
    "Update for {app} to version %s is available." : "Actualización para {app} a la versión %s está disponible.",
    "Update notification" : "Notificación de actualización",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Muestra notificaciones de actualizaciones para Nexcloud y provee el SSO para el actualizador.",
    "Update" : "Actualizar",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "La versión que usás yo no está mantenida. Por favor, asegurate de actualizar a una versión reciente tan pronto como sea posible.",
    "Apps missing compatible version" : "Apps sin versión compatible",
    "View in store" : "Ver en la tienda",
    "Apps with compatible version" : "Apps con versión compatible",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Tenga en cuenta que el actualizador web no se recomienda cuando la instancia tiene más de 100 usuarios. Por favor, utilice el actualizador de línea de comandos en su lugar.",
    "Open updater" : "Abrir actualizador",
    "Download now" : "Descargar ahora",
    "Please use the command line updater to update." : "Por favor, utilice el actualizador de línea de comandos para actualizar.",
    "What's new?" : "¿Qué novedades hay?",
    "View changelog" : "Ver registro de cambios",
    "The update check is not yet finished. Please refresh the page." : "La comprobación de actualizaciones no ha finalizado aún. Por favor, recargá la página.",
    "Your version is up to date." : "Su versión está actualizada.",
    "A non-default update server is in use to be checked for updates:" : "Se está usando un servidor de actualizaciones no estándar para comprobar las actualizaciones:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Siempre puedes actualizar a una versión más reciente. Pero no podrás volver a una versión anterior estable.",
    "Notify members of the following groups about available updates:" : "Notificar a los miembros de los siguientes grupos de las actualizaciones disponibles:",
    "Only notifications for app updates are available." : "Solo están disponibles las notificaciones para actualizaciones de apps.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "El canal de actualización seleccionado hace que las notificaciones dedicadas al servidor sean obsoletas. ",
    "The selected update channel does not support updates of the server." : "El canal de actualización seleccionado no soporta actualizaciones del servidor. ",
    "A new version is available: <strong>{newVersionString}</strong>" : "Una versión más reciente está disponible: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Tenga en cuenta que tras un nueva lanzamiento, la actualización sólo se mostrará después de la primera versión menor o posterior. Las nuevas versiones se distribuyen entre nuestros usuarios a lo largo del tiempo y a veces se omite una versión cuando se encuentran problemas. Obtenga  más información sobre las actualizaciones y los canales de lanzamiento en {link}",
    "Checked on {lastCheckedDate}" : "Verificado el {lastCheckedDate}",
    "Checking apps for compatible versions" : "Comprobando que las apps tengan actualizaciones compatibles",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Por favor, asegurate de que tu archivo config.php no establezca <samp>appstoreenabled</samp> a \"false\".",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "No se ha podido conectar a la App Store o no se ha devuelto ninguna actualización. Busque manualmente las actualizaciones o asegúrese de que su servidor tiene acceso a Internet y pueda conectarse a la App Store.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Todas</strong> las apps son compatibles con esta versión de Nextcloud.",
    "Enterprise" : "Enterprise",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Para uso empresarial. Proporciona siempre el último nivel de actualización, pero no realiza inmediatamente la actualización a la siguiente versión mayor. La actualización ocurre cuando Nextcloud GmbH ha realizado una revisión dedicada, pruebas para despliegues a gran escala y servicios críticos. Este canal está disponible únicamente para los clientes del paquete Nextcloud Enterprise.",
    "Stable" : "Estable",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Es la versión estable más reciente. Es adecuada para uso en producción y siempre se actualizará a la última versión principal.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Es la versión preliminar para poder probar nuevas características, no para entornos de producción.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["La app <strong>%n</strong> no tiene una versión disponible compatible con esta versión de Nextcloud.","Las apps 1%n1 no tienen una versión disponible compatible con esta versión de Nextcloud.","Las apps <strong>%n</strong> no tienen una versión compatible con esta versión de Nextcloud."],
    "Update for %1$s to version %2$s is available." : "La actualización para %1$s a la versión %2$s está disponible.",
    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Podés cambiar el canal de actualización a continuación, lo que también afecta a la página de gestión de aplicaciones. Por ejemplo, después de cambiar al canal beta, las actualizaciones de aplicaciones beta se ofrecerán en la página de gestión de aplicaciones.",
    "Update channel:" : "Actualizar el canal:"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
